#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @File   : __init__.py.py
# @Author : mocobk
# @Email  : mailmzb@qq.com
# @Time   : 2019/9/13 19:52
from .logger import Logger as logger

__all__ = ['logger']
